==> ibiz-cloud-core-8.1.0.371-sources.jar: net/ibizsys/central/cloud/core/IServiceSystemRuntime.java <==
package net.ibizsys.central.cloud.core;

import net.ibizsys.central.ISystemRuntime;
import net.ibizsys.central.cloud.core.security.IAuthenticationUser;
import net.ibizsys.central.cloud.core.security.ISystemAccessManager;
import net.ibizsys.central.cloud.core.util.IRTCodeUtils;
import net.ibizsys.central.cloud.core.util.domain.AppData;

public interface IServiceSystemRuntime extends ISystemRuntime {

	/**
	 * 系统事件：系统关闭
	 */
	public final static String SYSTEMEVENT_SHUTDOWN = "SHUTDOWN";
	
	
	/**
	 * 参数：启用的服务接口，忽略服务总线默认接口
	 */
	public final static String PARAM_ENABLEAPIS_NOSERVICEHUB = "-noservicehub";
	
	
	
	/**
	 * 参数：数据流系统标识
	 */
	public final static String PARAM_DATAFLOWSYSTEMID = "dataflowsystemid";
	
	
	/**
	 * 获取系统访问管理对象
	 */
	ISystemAccessManager getSystemAccessManager();
	
	
	/**
	 * 获取系统功能运行时
	 * @param cls
	 * @param bTryMode
	 * @param bSystemOnly 仅从当前系统获取
	 * @return
	 */
	<T> T getSysUtilRuntime(Class<T> cls, boolean bTryMode, boolean bSystemOnly);
	
	
	
	/**
	 * 调用获取应用数据
	 * @param strSystemTag
	 * @param strOrgId
	 * @param iAuthenticationUser
	 * @param objTag
	 * @return
	 * @throws Throwable
	 */
	AppData invokeGetAppData(String strSystemTag, String strOrgId, IAuthenticationUser iAuthenticationUser, Object objTag) throws Throwable;
	
	
	
	
	/**
	 * 是否启用默认的服务总线系统接口
	 * @return
	 */
	boolean isEnableServiceHubAPI();
	
	
	
	/**
	 * 关闭系统，执行释放
	 */
	void shutdown();
	
	
	
	/**
	 * 是否启用运行时代码模式
	 * @return
	 */
	boolean isEnableRTCodeMode();
	
	
	
	/**
	 * 是否启用生产模式
	 * @return
	 */
	boolean isEnableProdMode();
	
	
	
	
	/**
	 * 获取数据流系统标识
	 * @return
	 */
	String getDataFlowSystemId();
	
	
	
	
	/**
	 * 获取RT代码功能组件
	 * @return
	 */
	IRTCodeUtils getRTCodeUtils();
}

==> ibiz-cloud-core-8.1.0.458-sources.jar: net/ibizsys/central/cloud/core/IServiceSystemRuntime.java <==
package net.ibizsys.central.cloud.core;

import net.ibizsys.central.ISystemRuntime;
import net.ibizsys.central.cloud.core.security.IAuthenticationUser;
import net.ibizsys.central.cloud.core.security.ISystemAccessManager;
import net.ibizsys.central.cloud.core.util.IRTCodeUtils;
import net.ibizsys.central.cloud.core.util.domain.AppData;
import net.ibizsys.central.cloud.core.util.domain.V2DeploySystem;

public interface IServiceSystemRuntime extends ISystemRuntime {

	/**
	 * 系统事件：系统关闭
	 */
	public final static String SYSTEMEVENT_SHUTDOWN = "SHUTDOWN";
	
	
	/**
	 * 参数：启用的服务接口，忽略服务总线默认接口
	 */
	public final static String PARAM_ENABLEAPIS_NOSERVICEHUB = "-noservicehub";
	
	
	
	/**
	 * 参数：数据流系统标识
	 */
	public final static String PARAM_DATAFLOWSYSTEMID = "dataflowsystemid";
	
	
	
	/**
	 * 参数：v2部署系统
	 */
	public final static String PARAM_V2DEPLOYSYSTEM = "v2deploysystem";

	
	
	
	/**
	 * 获取系统访问管理对象
	 */
	ISystemAccessManager getSystemAccessManager();
	
	
	/**
	 * 获取系统功能运行时
	 * @param cls
	 * @param bTryMode
	 * @param bSystemOnly 仅从当前系统获取
	 * @return
	 */
	<T> T getSysUtilRuntime(Class<T> cls, boolean bTryMode, boolean bSystemOnly);
	
	
	
	/**
	 * 调用获取应用数据
	 * @param strSystemTag
	 * @param strOrgId
	 * @param iAuthenticationUser
	 * @param objTag
	 * @return
	 * @throws Throwable
	 */
	AppData invokeGetAppData(String strSystemTag, String strOrgId, IAuthenticationUser iAuthenticationUser, Object objTag) throws Throwable;
	
	
	/**
	 * 调用获取应用数据
	 * @param strDCSystemTag
	 * @param iAuthenticationUser
	 * @param objTag
	 * @return
	 * @throws Throwable
	 */
	AppData invokeGetAppData(String strDCSystemTag, IAuthenticationUser iAuthenticationUser, Object objTag) throws Throwable;
	
	
	/**
	 * 是否启用默认的服务总线系统接口
	 * @return
	 */
	boolean isEnableServiceHubAPI();
	
	
	
	/**
	 * 关闭系统，执行释放
	 */
	void shutdown();
	
	
	
	/**
	 * 是否启用运行时代码模式
	 * @return
	 */
	boolean isEnableRTCodeMode();
	
	
	
	/**
	 * 是否启用生产模式
	 * @return
	 */
	boolean isEnableProdMode();
	
	
	
	
	/**
	 * 获取数据流系统标识
	 * @return
	 */
	String getDataFlowSystemId();
	

	
	/**
	 * 获取RT代码功能组件
	 * @return
	 */
	IRTCodeUtils getRTCodeUtils();
	
	
	
	/**
	 * 获取V2部署系统信息
	 * @return
	 */
	V2DeploySystem getV2DeploySystem();
	
	
	
	/**
	 * 是否支持扩展
	 * @return
	 */
	boolean isEnableExtension();
	
	
	
	/**
	 * 获取扩展标识
	 * @return
	 */
	String getExtensionId();
	
	
	/**
	 * 获取扩展会话标识
	 * @return
	 */
	String getExtensionSessionId();
	
}
